import { JsXmlSaxParser } from '../JsXmlSaxParser/index.js';
import { bindParsing } from './bindParsing.js';
export const createXmlToCsvTransformer = (mapping) => {
    const parser = new JsXmlSaxParser();
    return async function* (source) {
        const outputRowsContainer = {
            rows: []
        };
        bindParsing(outputRowsContainer, parser, mapping);
        if (parser.isStopped()) {
            await parser.start();
        }
        for await (const chunk of source) {
            parser.write(chunk);
            // await setImmediate() // Нет необходимости парсинг должен быть синхронной операцией
            if (outputRowsContainer.rows.length > 0) {
                let isParsingComplete = false;
                const csvRows = [];
                for (const rowContainer of outputRowsContainer.rows) {
                    if (rowContainer.end === false) {
                        csvRows.push(rowContainer.row);
                    }
                    else {
                        isParsingComplete = true;
                        break;
                    }
                }
                yield csvRows;
                if (isParsingComplete) {
                    return;
                }
                outputRowsContainer.rows = [];
            }
        }
    };
};
//# sourceMappingURL=createXmlToCsvTransformer.js.map